summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--misc/drivers/rtl8187x/rtl8187x.c2
-rw-r--r--nuttx/arch/arm/src/tiva/tiva_ethernet.c4
-rw-r--r--nuttx/arch/sim/src/up_netdriver.c2
-rw-r--r--nuttx/drivers/net/dm90x0.c2
-rw-r--r--nuttx/drivers/net/enc28j60.c2
-rw-r--r--nuttx/drivers/net/encx24j600.c2
-rw-r--r--nuttx/drivers/net/slip.c6
-rw-r--r--nuttx/include/nuttx/net/arp.h2
-rw-r--r--nuttx/include/nuttx/net/icmp.h4
-rw-r--r--nuttx/include/nuttx/net/igmp.h8
-rw-r--r--nuttx/include/nuttx/net/ip.h4
-rw-r--r--nuttx/include/nuttx/net/netconfig.h12
-rw-r--r--nuttx/include/nuttx/net/netdev.h2
-rw-r--r--nuttx/include/nuttx/net/tcp.h9
-rw-r--r--nuttx/include/nuttx/net/udp.h4
-rw-r--r--nuttx/net/arp/arp_inout.c12
-rw-r--r--nuttx/net/devif/devif_input.c10
-rw-r--r--nuttx/net/icmp/icmp_input.c4
-rw-r--r--nuttx/net/icmp/icmp_ping.c4
-rw-r--r--nuttx/net/icmp/icmp_poll.c4
-rw-r--r--nuttx/net/icmp/icmp_send.c6
-rw-r--r--nuttx/net/igmp/igmp_input.c6
-rw-r--r--nuttx/net/igmp/igmp_poll.c4
-rw-r--r--nuttx/net/igmp/igmp_send.c12
-rw-r--r--nuttx/net/pkt/pkt_poll.c4
-rw-r--r--nuttx/net/socket/net_sendfile.c2
-rw-r--r--nuttx/net/socket/recvfrom.c4
-rw-r--r--nuttx/net/tcp/tcp_appsend.c8
-rw-r--r--nuttx/net/tcp/tcp_conn.c4
-rw-r--r--nuttx/net/tcp/tcp_input.c48
-rw-r--r--nuttx/net/tcp/tcp_poll.c4
-rw-r--r--nuttx/net/tcp/tcp_send.c14
-rw-r--r--nuttx/net/tcp/tcp_send_buffered.c2
-rw-r--r--nuttx/net/tcp/tcp_send_unbuffered.c2
-rw-r--r--nuttx/net/tcp/tcp_timer.c8
-rw-r--r--nuttx/net/udp/udp_input.c10
-rw-r--r--nuttx/net/udp/udp_poll.c4
-rw-r--r--nuttx/net/udp/udp_send.c6
-rw-r--r--nuttx/net/utils/net_chksum.c10
39 files changed, 128 insertions, 129 deletions
diff --git a/misc/drivers/rtl8187x/rtl8187x.c b/misc/drivers/rtl8187x/rtl8187x.c
index f39e88f9f..597700bb9 100644
--- a/misc/drivers/rtl8187x/rtl8187x.c
+++ b/misc/drivers/rtl8187x/rtl8187x.c
@@ -2112,7 +2112,7 @@ static inline int rtl8187x_receive(FAR struct rtl8187x_state_s *priv,
* and an Ethernet header
*/
- if (iolen < NET_LLH_LEN + SIZEOF_RXDESC)
+ if (iolen < NET_LL_HDRLEN + SIZEOF_RXDESC)
{
RTL8187X_STATS(priv, rxtoosmall);
RTL8187X_STATS(priv, rxdropped);
diff --git a/nuttx/arch/arm/src/tiva/tiva_ethernet.c b/nuttx/arch/arm/src/tiva/tiva_ethernet.c
index e200f7d75..48cc02324 100644
--- a/nuttx/arch/arm/src/tiva/tiva_ethernet.c
+++ b/nuttx/arch/arm/src/tiva/tiva_ethernet.c
@@ -515,7 +515,7 @@ static int tiva_transmit(struct tiva_driver_s *priv)
pktlen = priv->ld_dev.d_len;
nllvdbg("Sending packet, pktlen: %d\n", pktlen);
- DEBUGASSERT(pktlen > NET_LLH_LEN);
+ DEBUGASSERT(pktlen > NET_LL_HDRLEN);
dbuf = priv->ld_dev.d_buf;
regval = (uint32_t)(pktlen - 14);
@@ -677,7 +677,7 @@ static void tiva_receive(struct tiva_driver_s *priv)
* and 4 byte FCS that are not copied into the uIP packet.
*/
- if (pktlen > (CONFIG_NET_BUFSIZE + 6) || pktlen <= (NET_LLH_LEN + 6))
+ if (pktlen > (CONFIG_NET_BUFSIZE + 6) || pktlen <= (NET_LL_HDRLEN + 6))
{
int wordlen;
diff --git a/nuttx/arch/sim/src/up_netdriver.c b/nuttx/arch/sim/src/up_netdriver.c
index 7102e05d8..45c106b7f 100644
--- a/nuttx/arch/sim/src/up_netdriver.c
+++ b/nuttx/arch/sim/src/up_netdriver.c
@@ -155,7 +155,7 @@ void netdriver_loop(void)
* MAC address
*/
- if (g_sim_dev.d_len > NET_LLH_LEN && up_comparemac(BUF->ether_dhost, &g_sim_dev.d_mac) == 0)
+ if (g_sim_dev.d_len > NET_LL_HDRLEN && up_comparemac(BUF->ether_dhost, &g_sim_dev.d_mac) == 0)
{
/* We only accept IP packets of the configured type and ARP packets */
diff --git a/nuttx/drivers/net/dm90x0.c b/nuttx/drivers/net/dm90x0.c
index 093a84807..ce2753287 100644
--- a/nuttx/drivers/net/dm90x0.c
+++ b/nuttx/drivers/net/dm90x0.c
@@ -963,7 +963,7 @@ static void dm9x_receive(struct dm9x_driver_s *dm9x)
/* Also check if the packet is a valid size for the uIP configuration */
- else if (rx.desc.rx_len < NET_LLH_LEN || rx.desc.rx_len > (CONFIG_NET_BUFSIZE + 2))
+ else if (rx.desc.rx_len < NET_LL_HDRLEN || rx.desc.rx_len > (CONFIG_NET_BUFSIZE + 2))
{
#if defined(CONFIG_DM9X_STATS)
dm9x->dm_nrxlengtherrors++;
diff --git a/nuttx/drivers/net/enc28j60.c b/nuttx/drivers/net/enc28j60.c
index ed5ea8379..e0a1f207d 100644
--- a/nuttx/drivers/net/enc28j60.c
+++ b/nuttx/drivers/net/enc28j60.c
@@ -1483,7 +1483,7 @@ static void enc_pktif(FAR struct enc_driver_s *priv)
/* Check for a usable packet length (4 added for the CRC) */
- else if (pktlen > (CONFIG_NET_BUFSIZE + 4) || pktlen <= (NET_LLH_LEN + 4))
+ else if (pktlen > (CONFIG_NET_BUFSIZE + 4) || pktlen <= (NET_LL_HDRLEN + 4))
{
nlldbg("Bad packet size dropped (%d)\n", pktlen);
#ifdef CONFIG_ENC28J60_STATS
diff --git a/nuttx/drivers/net/encx24j600.c b/nuttx/drivers/net/encx24j600.c
index 3c1b5c43a..45eca23e9 100644
--- a/nuttx/drivers/net/encx24j600.c
+++ b/nuttx/drivers/net/encx24j600.c
@@ -1650,7 +1650,7 @@ static void enc_pktif(FAR struct enc_driver_s *priv)
/* Check for a usable packet length (4 added for the CRC) */
- else if (pktlen > (CONFIG_NET_BUFSIZE + 4) || pktlen <= (NET_LLH_LEN + 4))
+ else if (pktlen > (CONFIG_NET_BUFSIZE + 4) || pktlen <= (NET_LL_HDRLEN + 4))
{
nlldbg("Bad packet size dropped (%d)\n", pktlen);
diff --git a/nuttx/include/nuttx/net/arp.h b/nuttx/include/nuttx/net/arp.h
index 7b75007ac..7c19039dd 100644
--- a/nuttx/include/nuttx/net/arp.h
+++ b/nuttx/include/nuttx/net/arp.h
@@ -67,7 +67,7 @@
/* Size of the Ethernet header */
-#define ETHHDR_LEN 14 /* Minimum size: 2*6 + 2 */
+#define ETH_HDRLEN 14 /* Minimum size: 2*6 + 2 */
/****************************************************************************
* Public Types
diff --git a/nuttx/include/nuttx/net/icmp.h b/nuttx/include/nuttx/net/icmp.h
index ae8dcf9db..722121b3a 100644
--- a/nuttx/include/nuttx/net/icmp.h
+++ b/nuttx/include/nuttx/net/icmp.h
@@ -103,8 +103,8 @@
/* Header sizes */
-#define UIP_ICMPH_LEN 4 /* Size of ICMP header */
-#define UIP_IPICMPH_LEN (UIP_ICMPH_LEN + IPHDR_LEN) /* Size of IP + ICMP header */
+#define ICMP_HDRLEN 4 /* Size of ICMP header */
+#define IPICMP_HDRLEN (ICMP_HDRLEN + IP_HDRLEN) /* Size of IP + ICMP header */
/****************************************************************************
* Public Type Definitions
diff --git a/nuttx/include/nuttx/net/igmp.h b/nuttx/include/nuttx/net/igmp.h
index 5770e585d..f15aa23b9 100644
--- a/nuttx/include/nuttx/net/igmp.h
+++ b/nuttx/include/nuttx/net/igmp.h
@@ -78,12 +78,12 @@
/* Header sizes:
*
- * UIP_IGMPH_LEN - Size of IGMP header in bytes
- * UIP_IPIGMPH_LEN - Size of IP + Size of IGMP header + Size of router alert
+ * IGMP_HDRLEN - Size of IGMP header in bytes
+ * IPIGMP_HDRLEN - Size of IP + Size of IGMP header + Size of router alert
*/
-#define UIP_IGMPH_LEN 8
-#define UIP_IPIGMPH_LEN (UIP_IGMPH_LEN + IPHDR_LEN + 4)
+#define IGMP_HDRLEN 8
+#define IPIGMP_HDRLEN (IGMP_HDRLEN + IP_HDRLEN + 4)
/* Group flags */
diff --git a/nuttx/include/nuttx/net/ip.h b/nuttx/include/nuttx/net/ip.h
index 12f8f9c03..5d44149a7 100644
--- a/nuttx/include/nuttx/net/ip.h
+++ b/nuttx/include/nuttx/net/ip.h
@@ -73,9 +73,9 @@
/* Header sizes */
#ifdef CONFIG_NET_IPv6
-# define IPHDR_LEN 40 /* Size of IP header */
+# define IP_HDRLEN 40 /* Size of IP header */
#else
-# define IPHDR_LEN 20 /* Size of IP header */
+# define IP_HDRLEN 20 /* Size of IP header */
#endif
/****************************************************************************
diff --git a/nuttx/include/nuttx/net/netconfig.h b/nuttx/include/nuttx/net/netconfig.h
index 73f4cea00..fa5a88a00 100644
--- a/nuttx/include/nuttx/net/netconfig.h
+++ b/nuttx/include/nuttx/net/netconfig.h
@@ -89,11 +89,11 @@
# ifdef CONFIG_NET_IPv6
# error "SLIP is not implemented for IPv6"
# endif
-# define NET_LLH_LEN 0
+# define NET_LL_HDRLEN 0
#else
# define CONFIG_NET_ETHERNET 1
# define CONFIG_NET_ARP 1
-# define NET_LLH_LEN 14
+# define NET_LL_HDRLEN 14
#endif
/* Layer 3/4 Configuration Options ******************************************/
@@ -158,10 +158,10 @@
#endif
/* The UDP maximum packet size. This is should not be to set to more
- * than CONFIG_NET_BUFSIZE - NET_LLH_LEN - UIP_IPUDPH_LEN.
+ * than CONFIG_NET_BUFSIZE - NET_LL_HDRLEN - IPUDP_HDRLEN.
*/
-#define UDP_MSS (CONFIG_NET_BUFSIZE - NET_LLH_LEN - UIP_IPUDPH_LEN)
+#define UDP_MSS (CONFIG_NET_BUFSIZE - NET_LL_HDRLEN - IPUDP_HDRLEN)
/* TCP configuration options */
@@ -223,10 +223,10 @@
#define UIP_MAXSYNRTX 5
/* The TCP maximum segment size. This is should not be set to more
- * than CONFIG_NET_BUFSIZE - NET_LLH_LEN - UIP_TCPIP_HLEN.
+ * than CONFIG_NET_BUFSIZE - NET_LL_HDRLEN - IPTCP_HDRLEN.
*/
-#define TCP_MSS (CONFIG_NET_BUFSIZE - NET_LLH_LEN - UIP_TCPIP_HLEN)
+#define TCP_MSS (CONFIG_NET_BUFSIZE - NET_LL_HDRLEN - IPTCP_HDRLEN)
/* The size of the advertised receiver's window.
*
diff --git a/nuttx/include/nuttx/net/netdev.h b/nuttx/include/nuttx/net/netdev.h
index efe74f818..41d9888b7 100644
--- a/nuttx/include/nuttx/net/netdev.h
+++ b/nuttx/include/nuttx/net/netdev.h
@@ -112,7 +112,7 @@ struct net_driver_s
* driver should place incoming data into this buffer. When sending data,
* the device driver should read the link level headers and the TCP/IP
* headers from this buffer. The size of the link level headers is
- * configured by the NET_LLH_LEN define.
+ * configured by the NET_LL_HDRLEN define.
*
* uIP will handle only a single buffer for both incoming and outgoing
* packets. However, the drive design may be concurrently send and
diff --git a/nuttx/include/nuttx/net/tcp.h b/nuttx/include/nuttx/net/tcp.h
index d34ee03ea..478c70a01 100644
--- a/nuttx/include/nuttx/net/tcp.h
+++ b/nuttx/include/nuttx/net/tcp.h
@@ -104,9 +104,8 @@
/* TCP header sizes */
-#define UIP_TCPH_LEN 20 /* Size of TCP header */
-#define UIP_IPTCPH_LEN (UIP_TCPH_LEN + IPHDR_LEN) /* Size of IP + TCP header */
-#define UIP_TCPIP_HLEN UIP_IPTCPH_LEN
+#define TCP_HDRLEN 20 /* Size of TCP header */
+#define IPTCP_HDRLEN (TCP_HDRLEN + IP_HDRLEN) /* Size of IP + TCP header */
/* Initial minimum MSS according to RFC 879
*
@@ -121,9 +120,9 @@
*/
#if TCP_MSS > 576
-# define UIP_TCP_INITIAL_MSS 576
+# define TCP_INITIAL_MSS 576
#else
-# define UIP_TCP_INITIAL_MSS TCP_MSS
+# define TCP_INITIAL_MSS TCP_MSS
#endif
#ifdef CONFIG_NET_TCP_WRITE_BUFFERS
diff --git a/nuttx/include/nuttx/net/udp.h b/nuttx/include/nuttx/net/udp.h
index 05b5c2105..094fc381a 100644
--- a/nuttx/include/nuttx/net/udp.h
+++ b/nuttx/include/nuttx/net/udp.h
@@ -62,8 +62,8 @@
/* Header sizes */
-#define UIP_UDPH_LEN 8 /* Size of UDP header */
-#define UIP_IPUDPH_LEN (UIP_UDPH_LEN + IPHDR_LEN) /* Size of IP + UDP header */
+#define UDP_HDRLEN 8 /* Size of UDP header */
+#define IPUDP_HDRLEN (UDP_HDRLEN + IP_HDRLEN) /* Size of IP + UDP header */
/****************************************************************************
* Public Type Definitions
diff --git a/nuttx/net/arp/arp_inout.c b/nuttx/net/arp/arp_inout.c
index 4bd9970e6..98d199f10 100644
--- a/nuttx/net/arp/arp_inout.c
+++ b/nuttx/net/arp/arp_inout.c
@@ -86,8 +86,8 @@
#define RASIZE 4 /* Size of ROUTER ALERT */
#define ETHBUF ((struct eth_hdr_s *)&dev->d_buf[0])
-#define ARPBUF ((struct arp_hdr_s *)&dev->d_buf[NET_LLH_LEN])
-#define IPBUF ((struct arp_iphdr_s *)&dev->d_buf[NET_LLH_LEN])
+#define ARPBUF ((struct arp_hdr_s *)&dev->d_buf[NET_LL_HDRLEN])
+#define IPBUF ((struct arp_iphdr_s *)&dev->d_buf[NET_LL_HDRLEN])
/****************************************************************************
* Private Types
@@ -239,7 +239,7 @@ void arp_arpin(struct net_driver_s *dev)
struct arp_hdr_s *parp = ARPBUF;
in_addr_t ipaddr;
- if (dev->d_len < (sizeof(struct arp_hdr_s) + NET_LLH_LEN))
+ if (dev->d_len < (sizeof(struct arp_hdr_s) + NET_LL_HDRLEN))
{
nlldbg("Too small\n");
dev->d_len = 0;
@@ -279,7 +279,7 @@ void arp_arpin(struct net_driver_s *dev)
arp_dump(parp);
peth->type = HTONS(ETHTYPE_ARP);
- dev->d_len = sizeof(struct arp_hdr_s) + NET_LLH_LEN;
+ dev->d_len = sizeof(struct arp_hdr_s) + NET_LL_HDRLEN;
}
break;
@@ -440,7 +440,7 @@ void arp_out(struct net_driver_s *dev)
arp_dump(parp);
peth->type = HTONS(ETHTYPE_ARP);
- dev->d_len = sizeof(struct arp_hdr_s) + NET_LLH_LEN;
+ dev->d_len = sizeof(struct arp_hdr_s) + NET_LL_HDRLEN;
return;
}
@@ -453,7 +453,7 @@ void arp_out(struct net_driver_s *dev)
memcpy(peth->src, dev->d_mac.ether_addr_octet, ETHER_ADDR_LEN);
peth->type = HTONS(ETHTYPE_IP);
- dev->d_len += NET_LLH_LEN;
+ dev->d_len += NET_LL_HDRLEN;
}
#endif /* CONFIG_NET_ARP */
diff --git a/nuttx/net/devif/devif_input.c b/nuttx/net/devif/devif_input.c
index f1c2cdbe6..dad20671b 100644
--- a/nuttx/net/devif/devif_input.c
+++ b/nuttx/net/devif/devif_input.c
@@ -107,13 +107,13 @@
/* Macros. */
-#define BUF ((FAR struct net_iphdr_s *)&dev->d_buf[NET_LLH_LEN])
+#define BUF ((FAR struct net_iphdr_s *)&dev->d_buf[NET_LL_HDRLEN])
#define FBUF ((FAR struct net_iphdr_s *)&g_reassembly_buffer[0])
/* IP fragment re-assembly */
#define IP_MF 0x20
-#define UIP_REASS_BUFSIZE (CONFIG_NET_BUFSIZE - NET_LLH_LEN)
+#define UIP_REASS_BUFSIZE (CONFIG_NET_BUFSIZE - NET_LL_HDRLEN)
#define UIP_REASS_FLAG_LASTFRAG 0x01
/****************************************************************************
@@ -162,7 +162,7 @@ static uint8_t devif_reassembly(void)
if (!g_reassembly_timer)
{
- memcpy(g_reassembly_buffer, &pbuf->vhl, IPHDR_LEN);
+ memcpy(g_reassembly_buffer, &pbuf->vhl, IP_HDRLEN);
g_reassembly_timer = UIP_REASS_MAXAGE;
g_reassembly_flags = 0;
@@ -195,7 +195,7 @@ static uint8_t devif_reassembly(void)
/* Copy the fragment into the reassembly buffer, at the right offset. */
- memcpy(&g_reassembly_buffer[IPHDR_LEN + offset], (char *)pbuf + (int)((pbuf->vhl & 0x0f) * 4), len);
+ memcpy(&g_reassembly_buffer[IP_HDRLEN + offset], (char *)pbuf + (int)((pbuf->vhl & 0x0f) * 4), len);
/* Update the bitmap. */
@@ -367,7 +367,7 @@ int devif_input(FAR struct net_driver_s *dev)
* the size of the IPv6 header (40 bytes).
*/
- iplen = (pbuf->len[0] << 8) + pbuf->len[1] + IPHDR_LEN;
+ iplen = (pbuf->len[0] << 8) + pbuf->len[1] + IP_HDRLEN;
#else
iplen = (pbuf->len[0] << 8) + pbuf->len[1];
#endif /* CONFIG_NET_IPv6 */
diff --git a/nuttx/net/icmp/icmp_input.c b/nuttx/net/icmp/icmp_input.c
index 5107dbfdf..6ef90ae72 100644
--- a/nuttx/net/icmp/icmp_input.c
+++ b/nuttx/net/icmp/icmp_input.c
@@ -66,7 +66,7 @@
* Pre-processor Definitions
****************************************************************************/
-#define ICMPBUF ((struct icmp_iphdr_s *)&dev->d_buf[NET_LLH_LEN])
+#define ICMPBUF ((struct icmp_iphdr_s *)&dev->d_buf[NET_LL_HDRLEN])
/****************************************************************************
* Public Variables
@@ -151,7 +151,7 @@ void icmp_input(FAR struct net_driver_s *dev)
/* The slow way... sum over the ICMP message */
picmp->icmpchksum = 0;
- picmp->icmpchksum = ~icmp_chksum(dev, (((uint16_t)picmp->len[0] << 8) | (uint16_t)picmp->len[1]) - IPHDR_LEN);
+ picmp->icmpchksum = ~icmp_chksum(dev, (((uint16_t)picmp->len[0] << 8) | (uint16_t)picmp->len[1]) - IP_HDRLEN);
if (picmp->icmpchksum == 0)
{
picmp->icmpchksum = 0xffff;
diff --git a/nuttx/net/icmp/icmp_ping.c b/nuttx/net/icmp/icmp_ping.c
index 4b460a210..2124765b9 100644
--- a/nuttx/net/icmp/icmp_ping.c
+++ b/nuttx/net/icmp/icmp_ping.c
@@ -64,8 +64,8 @@
* Pre-processor Definitions
****************************************************************************/
-#define ICMPBUF ((struct icmp_iphdr_s *)&dev->d_buf[NET_LLH_LEN])
-#define ICMPDAT (&dev->d_buf[NET_LLH_LEN + sizeof(struct icmp_iphdr_s)])
+#define ICMPBUF ((struct icmp_iphdr_s *)&dev->d_buf[NET_LL_HDRLEN])
+#define ICMPDAT (&dev->d_buf[NET_LL_HDRLEN + sizeof(struct icmp_iphdr_s)])
/* Allocate a new ICMP data callback */
diff --git a/nuttx/net/icmp/icmp_poll.c b/nuttx/net/icmp/icmp_poll.c
index b6604117f..43ae31154 100644
--- a/nuttx/net/icmp/icmp_poll.c
+++ b/nuttx/net/icmp/icmp_poll.c
@@ -90,8 +90,8 @@ void icmp_poll(FAR struct net_driver_s *dev)
{
/* Setup for the application callback */
- dev->d_appdata = &dev->d_buf[NET_LLH_LEN + UIP_IPICMPH_LEN];
- dev->d_snddata = &dev->d_buf[NET_LLH_LEN + UIP_IPICMPH_LEN];
+ dev->d_appdata = &dev->d_buf[NET_LL_HDRLEN + IPICMP_HDRLEN];
+ dev->d_snddata = &dev->d_buf[NET_LL_HDRLEN + IPICMP_HDRLEN];
dev->d_len = 0;
dev->d_sndlen = 0;
diff --git a/nuttx/net/icmp/icmp_send.c b/nuttx/net/icmp/icmp_send.c
index d5cdbc4d3..d4c6364b8 100644
--- a/nuttx/net/icmp/icmp_send.c
+++ b/nuttx/net/icmp/icmp_send.c
@@ -57,7 +57,7 @@
* Pre-processor Definitions
****************************************************************************/
-#define ICMPBUF ((struct icmp_iphdr_s *)&dev->d_buf[NET_LLH_LEN])
+#define ICMPBUF ((struct icmp_iphdr_s *)&dev->d_buf[NET_LL_HDRLEN])
/****************************************************************************
* Public Variables
@@ -102,13 +102,13 @@ void icmp_send(FAR struct net_driver_s *dev, FAR net_ipaddr_t *destaddr)
* the IP and ICMP headers (and, eventually, the Ethernet header)
*/
- dev->d_len = dev->d_sndlen + UIP_IPICMPH_LEN;
+ dev->d_len = dev->d_sndlen + IPICMP_HDRLEN;
/* The total size of the data (for ICMP checksum calculation) includes
* the size of the ICMP header
*/
- dev->d_sndlen += UIP_ICMPH_LEN;
+ dev->d_sndlen += ICMP_HDRLEN;
/* Initialize the IP header. Note that for IPv6, the IP length field
* does not include the IPv6 IP header length.
diff --git a/nuttx/net/igmp/igmp_input.c b/nuttx/net/igmp/igmp_input.c
index 1eb09b193..886282569 100644
--- a/nuttx/net/igmp/igmp_input.c
+++ b/nuttx/net/igmp/igmp_input.c
@@ -61,7 +61,7 @@
* Pre-processor Definitions
****************************************************************************/
-#define IGMPBUF ((struct igmp_iphdr_s *)&dev->d_buf[NET_LLH_LEN])
+#define IGMPBUF ((struct igmp_iphdr_s *)&dev->d_buf[NET_LL_HDRLEN])
/****************************************************************************
* Private Functions
@@ -124,7 +124,7 @@ void igmp_input(struct net_driver_s *dev)
/* Verify the message length */
- if (dev->d_len < NET_LLH_LEN+UIP_IPIGMPH_LEN)
+ if (dev->d_len < NET_LL_HDRLEN+IPIGMP_HDRLEN)
{
IGMP_STATINCR(g_netstats.igmp.length_errors);
nlldbg("Length error\n");
@@ -133,7 +133,7 @@ void igmp_input(struct net_driver_s *dev)
/* Calculate and check the IGMP checksum */
- if (net_chksum((uint16_t*)&IGMPBUF->type, UIP_IGMPH_LEN) != 0)
+ if (net_chksum((uint16_t*)&IGMPBUF->type, IGMP_HDRLEN) != 0)
{
IGMP_STATINCR(g_netstats.igmp.chksum_errors);
nlldbg("Checksum error\n");
diff --git a/nuttx/net/igmp/igmp_poll.c b/nuttx/net/igmp/igmp_poll.c
index 8a16e47e4..147f9f810 100644
--- a/nuttx/net/igmp/igmp_poll.c
+++ b/nuttx/net/igmp/igmp_poll.c
@@ -151,8 +151,8 @@ void igmp_poll(FAR struct net_driver_s *dev)
/* Setup the poll operation */
- dev->d_appdata = &dev->d_buf[NET_LLH_LEN + UIP_IPIGMPH_LEN];
- dev->d_snddata = &dev->d_buf[NET_LLH_LEN + UIP_IPIGMPH_LEN];
+ dev->d_appdata = &dev->d_buf[NET_LL_HDRLEN + IPIGMP_HDRLEN];
+ dev->d_snddata = &dev->d_buf[NET_LL_HDRLEN + IPIGMP_HDRLEN];
dev->d_len = 0;
dev->d_sndlen = 0;
diff --git a/nuttx/net/igmp/igmp_send.c b/nuttx/net/igmp/igmp_send.c
index c9ba71aa6..fdec85458 100644
--- a/nuttx/net/igmp/igmp_send.c
+++ b/nuttx/net/igmp/igmp_send.c
@@ -75,7 +75,7 @@
/* Buffer layout */
#define RASIZE (4)
-#define IGMPBUF ((struct igmp_iphdr_s *)&dev->d_buf[NET_LLH_LEN])
+#define IGMPBUF ((struct igmp_iphdr_s *)&dev->d_buf[NET_LL_HDRLEN])
/****************************************************************************
* Public Variables
@@ -129,11 +129,11 @@ void igmp_send(FAR struct net_driver_s *dev, FAR struct igmp_group_s *group,
* bytes for the ROUTER ALERT (and, eventually, the Ethernet header)
*/
- dev->d_len = UIP_IPIGMPH_LEN;
+ dev->d_len = IPIGMP_HDRLEN;
/* The total size of the data is the size of the IGMP header */
- dev->d_sndlen = UIP_IGMPH_LEN;
+ dev->d_sndlen = IGMP_HDRLEN;
/* Add the router alert option */
@@ -160,7 +160,7 @@ void igmp_send(FAR struct net_driver_s *dev, FAR struct igmp_group_s *group,
/* Calculate IP checksum. */
IGMPBUF->ipchksum = 0;
- IGMPBUF->ipchksum = ~igmp_chksum((FAR uint8_t *)IGMPBUF, IPHDR_LEN + RASIZE);
+ IGMPBUF->ipchksum = ~igmp_chksum((FAR uint8_t *)IGMPBUF, IP_HDRLEN + RASIZE);
/* Set up the IGMP message */
@@ -171,14 +171,14 @@ void igmp_send(FAR struct net_driver_s *dev, FAR struct igmp_group_s *group,
/* Calculate the IGMP checksum. */
IGMPBUF->chksum = 0;
- IGMPBUF->chksum = ~igmp_chksum(&IGMPBUF->type, UIP_IPIGMPH_LEN);
+ IGMPBUF->chksum = ~igmp_chksum(&IGMPBUF->type, IPIGMP_HDRLEN);
IGMP_STATINCR(g_netstats.igmp.poll_send);
IGMP_STATINCR(g_netstats.ip.sent);
nllvdbg("Outgoing IGMP packet length: %d (%d)\n",
dev->d_len, (IGMPBUF->len[0] << 8) | IGMPBUF->len[1]);
- igmp_dumppkt(RA, UIP_IPIGMPH_LEN + RASIZE);
+ igmp_dumppkt(RA, IPIGMP_HDRLEN + RASIZE);
}
#endif /* CONFIG_NET_IGMP */
diff --git a/nuttx/net/pkt/pkt_poll.c b/nuttx/net/pkt/pkt_poll.c
index 9019b1ddd..4701456be 100644
--- a/nuttx/net/pkt/pkt_poll.c
+++ b/nuttx/net/pkt/pkt_poll.c
@@ -103,8 +103,8 @@ void pkt_poll(FAR struct net_driver_s *dev, FAR struct pkt_conn_s *conn)
{
/* Setup for the application callback */
- dev->d_appdata = &dev->d_buf[NET_LLH_LEN + UIP_IPUDPH_LEN];
- dev->d_snddata = &dev->d_buf[NET_LLH_LEN + UIP_IPUDPH_LEN];
+ dev->d_appdata = &dev->d_buf[NET_LL_HDRLEN + IPUDP_HDRLEN];
+ dev->d_snddata = &dev->d_buf[NET_LL_HDRLEN + IPUDP_HDRLEN];
dev->d_len = 0;
dev->d_sndlen = 0;
diff --git a/nuttx/net/socket/net_sendfile.c b/nuttx/net/socket/net_sendfile.c
index 5ff8c6fe0..dfaf5e61f 100644
--- a/nuttx/net/socket/net_sendfile.c
+++ b/nuttx/net/socket/net_sendfile.c
@@ -77,7 +77,7 @@
# define CONFIG_NET_TCP_SPLIT_SIZE 40
#endif
-#define TCPBUF ((struct tcp_iphdr_s *)&dev->d_buf[NET_LLH_LEN])
+#define TCPBUF ((struct tcp_iphdr_s *)&dev->d_buf[NET_LL_HDRLEN])
/****************************************************************************
* Private Types
diff --git a/nuttx/net/socket/recvfrom.c b/nuttx/net/socket/recvfrom.c
index ccc037f4e..fbf03f9c7 100644
--- a/nuttx/net/socket/recvfrom.c
+++ b/nuttx/net/socket/recvfrom.c
@@ -75,8 +75,8 @@
* Definitions
****************************************************************************/
-#define UDPBUF ((struct udp_iphdr_s *)&dev->d_buf[NET_LLH_LEN])
-#define TCPBUF ((struct tcp_iphdr_s *)&dev->d_buf[NET_LLH_LEN])
+#define UDPBUF ((struct udp_iphdr_s *)&dev->d_buf[NET_LL_HDRLEN])
+#define TCPBUF ((struct tcp_iphdr_s *)&dev->d_buf[NET_LL_HDRLEN])
/****************************************************************************
* Private Types
diff --git a/nuttx/net/tcp/tcp_appsend.c b/nuttx/net/tcp/tcp_appsend.c
index 48f67a65a..9f5a824d1 100644
--- a/nuttx/net/tcp/tcp_appsend.c
+++ b/nuttx/net/tcp/tcp_appsend.c
@@ -112,7 +112,7 @@ void tcp_appsend(FAR struct net_driver_s *dev, FAR struct tcp_conn_s *conn,
conn->tcpstateflags = UIP_CLOSED;
nllvdbg("TCP state: UIP_CLOSED\n");
- tcp_send(dev, conn, TCP_RST | TCP_ACK, UIP_IPTCPH_LEN);
+ tcp_send(dev, conn, TCP_RST | TCP_ACK, IPTCP_HDRLEN);
}
/* Check for connection closed */
@@ -125,7 +125,7 @@ void tcp_appsend(FAR struct net_driver_s *dev, FAR struct tcp_conn_s *conn,
nllvdbg("TCP state: UIP_FIN_WAIT_1\n");
dev->d_sndlen = 0;
- tcp_send(dev, conn, TCP_FIN | TCP_ACK, UIP_IPTCPH_LEN);
+ tcp_send(dev, conn, TCP_FIN | TCP_ACK, IPTCP_HDRLEN);
}
/* None of the above */
@@ -204,14 +204,14 @@ void tcp_rexmit(FAR struct net_driver_s *dev, FAR struct tcp_conn_s *conn,
* the IP and TCP headers.
*/
- tcp_send(dev, conn, TCP_ACK | TCP_PSH, dev->d_sndlen + UIP_TCPIP_HLEN);
+ tcp_send(dev, conn, TCP_ACK | TCP_PSH, dev->d_sndlen + IPTCP_HDRLEN);
}
/* If there is no data to send, just send out a pure ACK if one is requested`. */
else if ((result & UIP_SNDACK) != 0)
{
- tcp_send(dev, conn, TCP_ACK, UIP_TCPIP_HLEN);
+ tcp_send(dev, conn, TCP_ACK, IPTCP_HDRLEN);
}
/* There is nothing to do -- drop the packet */
diff --git a/nuttx/net/tcp/tcp_conn.c b/nuttx/net/tcp/tcp_conn.c
index f1bc36557..3225177f8 100644
--- a/nuttx/net/tcp/tcp_conn.c
+++ b/nuttx/net/tcp/tcp_conn.c
@@ -522,7 +522,7 @@ FAR struct tcp_conn_s *tcp_alloc_accept(FAR struct tcp_iphdr_s *buf)
conn->nrtx = 0;
conn->lport = buf->destport;
conn->rport = buf->srcport;
- conn->mss = UIP_TCP_INITIAL_MSS;
+ conn->mss = TCP_INITIAL_MSS;
net_ipaddr_copy(conn->ripaddr, net_ip4addr_conv32(buf->srcipaddr));
conn->tcpstateflags = UIP_SYN_RCVD;
@@ -675,7 +675,7 @@ int tcp_connect(FAR struct tcp_conn_s *conn,
conn->tcpstateflags = UIP_SYN_SENT;
tcp_initsequence(conn->sndseq);
- conn->mss = UIP_TCP_INITIAL_MSS;
+ conn->mss = TCP_INITIAL_MSS;
conn->unacked = 1; /* TCP length of the SYN is one. */
conn->nrtx = 0;
conn->timer = 1; /* Send the SYN next time around. */
diff --git a/nuttx/net/tcp/tcp_poll.c b/nuttx/net/tcp/tcp_poll.c
index df8099a7f..fbd1af3e7 100644
--- a/nuttx/net/tcp/tcp_poll.c
+++ b/nuttx/net/tcp/tcp_poll.c
@@ -103,8 +103,8 @@ void tcp_poll(FAR struct net_driver_s *dev, FAR struct tcp_conn_s *conn)
{
/* Set up for the callback */
- dev->d_snddata = &dev->d_buf[UIP_IPTCPH_LEN + NET_LLH_LEN];
- dev->d_appdata = &dev->d_buf[UIP_IPTCPH_LEN + NET_LLH_LEN];
+ dev->d_snddata = &dev->d_buf[IPTCP_HDRLEN + NET_LL_HDRLEN];
+ dev->d_appdata = &dev->d_buf[IPTCP_HDRLEN + NET_LL_HDRLEN];
dev->d_len = 0;
dev->d_sndlen = 0;
diff --git a/nuttx/net/tcp/tcp_send.c b/nuttx/net/tcp/tcp_send.c
index ae8c31bec..85d01e5f3 100644
--- a/nuttx/net/tcp/tcp_send.c
+++ b/nuttx/net/tcp/tcp_send.c
@@ -60,7 +60,7 @@
* Pre-processor Definitions
****************************************************************************/
-#define BUF ((struct tcp_iphdr_s *)&dev->d_buf[NET_LLH_LEN])
+#define BUF ((struct tcp_iphdr_s *)&dev->d_buf[NET_LL_HDRLEN])
/****************************************************************************
* Public Variables
@@ -104,8 +104,8 @@ static void tcp_sendcomplete(FAR struct net_driver_s *dev)
* length.
*/
- pbuf->len[0] = ((dev->d_len - IPHDR_LEN) >> 8);
- pbuf->len[1] = ((dev->d_len - IPHDR_LEN) & 0xff);
+ pbuf->len[0] = ((dev->d_len - IP_HDRLEN) >> 8);
+ pbuf->len[1] = ((dev->d_len - IP_HDRLEN) & 0xff);
#else /* CONFIG_NET_IPv6 */
@@ -241,7 +241,7 @@ void tcp_send(FAR struct net_driver_s *dev, FAR struct tcp_conn_s *conn,
pbuf->flags = flags;
dev->d_len = len;
- pbuf->tcpoffset = (UIP_TCPH_LEN / 4) << 4;
+ pbuf->tcpoffset = (TCP_HDRLEN / 4) << 4;
tcp_sendcommon(dev, conn);
}
@@ -273,7 +273,7 @@ void tcp_reset(FAR struct net_driver_s *dev)
#endif
pbuf->flags = TCP_RST | TCP_ACK;
- dev->d_len = UIP_IPTCPH_LEN;
+ dev->d_len = IPTCP_HDRLEN;
pbuf->tcpoffset = 5 << 4;
/* Flip the seqno and ackno fields in the TCP header. */
@@ -360,8 +360,8 @@ void tcp_ack(FAR struct net_driver_s *dev, FAR struct tcp_conn_s *conn,
pbuf->optdata[1] = TCP_OPT_MSS_LEN;
pbuf->optdata[2] = (TCP_MSS) / 256;
pbuf->optdata[3] = (TCP_MSS) & 255;
- dev->d_len = UIP_IPTCPH_LEN + TCP_OPT_MSS_LEN;
- pbuf->tcpoffset = ((UIP_TCPH_LEN + TCP_OPT_MSS_LEN) / 4) << 4;
+ dev->d_len = IPTCP_HDRLEN + TCP_OPT_MSS_LEN;
+ pbuf->tcpoffset = ((TCP_HDRLEN + TCP_OPT_MSS_LEN) / 4) << 4;
/* Complete the common portions of the TCP message */
diff --git a/nuttx/net/tcp/tcp_send_buffered.c b/nuttx/net/tcp/tcp_send_buffered.c
index 7c3af9a15..c67f51632 100644
--- a/nuttx/net/tcp/tcp_send_buffered.c
+++ b/nuttx/net/tcp/tcp_send_buffered.c
@@ -78,7 +78,7 @@
* Pre-processor Definitions
****************************************************************************/
-#define TCPBUF ((struct tcp_iphdr_s *)&dev->d_buf[NET_LLH_LEN])
+#define TCPBUF ((struct tcp_iphdr_s *)&dev->d_buf[NET_LL_HDRLEN])
/* Debug */
diff --git a/nuttx/net/tcp/tcp_send_unbuffered.c b/nuttx/net/tcp/tcp_send_unbuffered.c
index 05e05f9a2..d0c02fb7d 100644
--- a/nuttx/net/tcp/tcp_send_unbuffered.c
+++ b/nuttx/net/tcp/tcp_send_unbuffered.c
@@ -70,7 +70,7 @@
# define CONFIG_NET_TCP_SPLIT_SIZE 40
#endif
-#define TCPBUF ((struct tcp_iphdr_s *)&dev->d_buf[NET_LLH_LEN])
+#define TCPBUF ((struct tcp_iphdr_s *)&dev->d_buf[NET_LL_HDRLEN])
/****************************************************************************
* Private Types
diff --git a/nuttx/net/tcp/tcp_timer.c b/nuttx/net/tcp/tcp_timer.c
index d508ab989..5bff56bc1 100644
--- a/nuttx/net/tcp/tcp_timer.c
+++ b/nuttx/net/tcp/tcp_timer.c
@@ -100,8 +100,8 @@ void tcp_timer(FAR struct net_driver_s *dev, FAR struct tcp_conn_s *conn,
{
uint8_t result;
- dev->d_snddata = &dev->d_buf[UIP_IPTCPH_LEN + NET_LLH_LEN];
- dev->d_appdata = &dev->d_buf[UIP_IPTCPH_LEN + NET_LLH_LEN];
+ dev->d_snddata = &dev->d_buf[IPTCP_HDRLEN + NET_LL_HDRLEN];
+ dev->d_appdata = &dev->d_buf[IPTCP_HDRLEN + NET_LL_HDRLEN];
/* Increase the TCP sequence number */
@@ -183,7 +183,7 @@ void tcp_timer(FAR struct net_driver_s *dev, FAR struct tcp_conn_s *conn,
/* We also send a reset packet to the remote host. */
- tcp_send(dev, conn, TCP_RST | TCP_ACK, UIP_IPTCPH_LEN);
+ tcp_send(dev, conn, TCP_RST | TCP_ACK, IPTCP_HDRLEN);
goto done;
}
@@ -234,7 +234,7 @@ void tcp_timer(FAR struct net_driver_s *dev, FAR struct tcp_conn_s *conn,
case UIP_LAST_ACK:
/* In all these states we should retransmit a FINACK. */
- tcp_send(dev, conn, TCP_FIN | TCP_ACK, UIP_IPTCPH_LEN);
+ tcp_send(dev, conn, TCP_FIN | TCP_ACK, IPTCP_HDRLEN);
goto done;
}
}
diff --git a/nuttx/net/udp/udp_input.c b/nuttx/net/udp/udp_input.c
index 95376586a..aaaa5a795 100644
--- a/nuttx/net/udp/udp_input.c
+++ b/nuttx/net/udp/udp_input.c
@@ -60,7 +60,7 @@
* Pre-processor Definitions
****************************************************************************/
-#define UDPBUF ((struct udp_iphdr_s *)&dev->d_buf[NET_LLH_LEN])
+#define UDPBUF ((struct udp_iphdr_s *)&dev->d_buf[NET_LL_HDRLEN])
/****************************************************************************
* Public Variables
@@ -112,9 +112,9 @@ int udp_input(FAR struct net_driver_s *dev)
* application sets d_sndlen, it has a packet to send.
*/
- dev->d_len -= UIP_IPUDPH_LEN;
+ dev->d_len -= IPUDP_HDRLEN;
#ifdef CONFIG_NET_UDP_CHECKSUMS
- dev->d_appdata = &dev->d_buf[NET_LLH_LEN + UIP_IPUDPH_LEN];
+ dev->d_appdata = &dev->d_buf[NET_LL_HDRLEN + IPUDP_HDRLEN];
if (pbuf->udpchksum != 0 && udp_chksum(dev) != 0xffff)
{
#ifdef CONFIG_NET_STATISTICS
@@ -136,8 +136,8 @@ int udp_input(FAR struct net_driver_s *dev)
/* Set-up for the application callback */
- dev->d_appdata = &dev->d_buf[NET_LLH_LEN + UIP_IPUDPH_LEN];
- dev->d_snddata = &dev->d_buf[NET_LLH_LEN + UIP_IPUDPH_LEN];
+ dev->d_appdata = &dev->d_buf[NET_LL_HDRLEN + IPUDP_HDRLEN];
+ dev->d_snddata = &dev->d_buf[NET_LL_HDRLEN + IPUDP_HDRLEN];
dev->d_sndlen = 0;
/* Perform the application callback */
diff --git a/nuttx/net/udp/udp_poll.c b/nuttx/net/udp/udp_poll.c
index 468878206..03f395952 100644
--- a/nuttx/net/udp/udp_poll.c
+++ b/nuttx/net/udp/udp_poll.c
@@ -100,8 +100,8 @@ void udp_poll(FAR struct net_driver_s *dev, FAR struct udp_conn_s *conn)
{
/* Set-up for the application callback */
- dev->d_appdata = &dev->d_buf[NET_LLH_LEN + UIP_IPUDPH_LEN];
- dev->d_snddata = &dev->d_buf[NET_LLH_LEN + UIP_IPUDPH_LEN];
+ dev->d_appdata = &dev->d_buf[NET_LL_HDRLEN + IPUDP_HDRLEN];
+ dev->d_snddata = &dev->d_buf[NET_LL_HDRLEN + IPUDP_HDRLEN];
dev->d_len = 0;
dev->d_sndlen = 0;
diff --git a/nuttx/net/udp/udp_send.c b/nuttx/net/udp/udp_send.c
index a56c91467..4b5e81ab5 100644
--- a/nuttx/net/udp/udp_send.c
+++ b/nuttx/net/udp/udp_send.c
@@ -62,7 +62,7 @@
* Pre-processor Definitions
****************************************************************************/
-#define UDPBUF ((struct udp_iphdr_s *)&dev->d_buf[NET_LLH_LEN])
+#define UDPBUF ((struct udp_iphdr_s *)&dev->d_buf[NET_LL_HDRLEN])
/****************************************************************************
* Public Variables
@@ -108,7 +108,7 @@ void udp_send(struct net_driver_s *dev, struct udp_conn_s *conn)
* the IP and UDP headers (and, eventually, the Ethernet header)
*/
- dev->d_len = dev->d_sndlen + UIP_IPUDPH_LEN;
+ dev->d_len = dev->d_sndlen + IPUDP_HDRLEN;
/* Initialize the IP header. Note that for IPv6, the IP length field
* does not include the IPv6 IP header length.
@@ -155,7 +155,7 @@ void udp_send(struct net_driver_s *dev, struct udp_conn_s *conn)
pudpbuf->srcport = conn->lport;
pudpbuf->destport = conn->rport;
- pudpbuf->udplen = HTONS(dev->d_sndlen + UIP_UDPH_LEN);
+ pudpbuf->udplen = HTONS(dev->d_sndlen + UDP_HDRLEN);
#ifdef CONFIG_NET_UDP_CHECKSUMS
/* Calculate UDP checksum. */
diff --git a/nuttx/net/utils/net_chksum.c b/nuttx/net/utils/net_chksum.c
index 188ec1bf1..a2eadf1bc 100644
--- a/nuttx/net/utils/net_chksum.c
+++ b/nuttx/net/utils/net_chksum.c
@@ -54,8 +54,8 @@
* Pre-processor Definitions
****************************************************************************/
-#define BUF ((struct net_iphdr_s *)&dev->d_buf[NET_LLH_LEN])
-#define ICMPBUF ((struct icmp_iphdr_s *)&dev->d_buf[NET_LLH_LEN])
+#define BUF ((struct net_iphdr_s *)&dev->d_buf[NET_LL_HDRLEN])
+#define ICMPBUF ((struct icmp_iphdr_s *)&dev->d_buf[NET_LL_HDRLEN])
/****************************************************************************
* Private Data
@@ -123,7 +123,7 @@ static uint16_t upper_layer_chksum(FAR struct net_driver_s *dev, uint8_t proto)
#ifdef CONFIG_NET_IPv6
upper_layer_len = (((uint16_t)(pbuf->len[0]) << 8) + pbuf->len[1]);
#else /* CONFIG_NET_IPv6 */
- upper_layer_len = (((uint16_t)(pbuf->len[0]) << 8) + pbuf->len[1]) - IPHDR_LEN;
+ upper_layer_len = (((uint16_t)(pbuf->len[0]) << 8) + pbuf->len[1]) - IP_HDRLEN;
#endif /* CONFIG_NET_IPv6 */
/* Verify some minimal assumptions */
@@ -145,7 +145,7 @@ static uint16_t upper_layer_chksum(FAR struct net_driver_s *dev, uint8_t proto)
/* Sum TCP header and data. */
- sum = chksum(sum, &dev->d_buf[IPHDR_LEN + NET_LLH_LEN], upper_layer_len);
+ sum = chksum(sum, &dev->d_buf[IP_HDRLEN + NET_LL_HDRLEN], upper_layer_len);
return (sum == 0) ? 0xffff : htons(sum);
}
@@ -285,7 +285,7 @@ uint16_t ip_chksum(FAR struct net_driver_s *dev)
{
uint16_t sum;
- sum = chksum(0, &dev->d_buf[NET_LLH_LEN], IPHDR_LEN);
+ sum = chksum(0, &dev->d_buf[NET_LL_HDRLEN], IP_HDRLEN);
return (sum == 0) ? 0xffff : htons(sum);
}
#endif /* CONFIG_NET_ARCH_CHKSUM */
diff --git a/nuttx/drivers/net/slip.c b/nuttx/drivers/net/slip.c
index b7c70af36..0780581a6 100644
--- a/nuttx/drivers/net/slip.c
+++ b/nuttx/drivers/net/slip.c
@@ -73,8 +73,8 @@
/* Configuration ************************************************************/
#if NET_LLH_LEN > 0
# error "NET_LLH_LEN must be set to zero"
#endif
#ifndef CONFIG_NET_NOINTS
@@ -708,7 +708,7 @@ static int slip_rxtask(int argc, char *argv[])
* enough to hold an IP header.
*/
- if (priv->rxlen >= IPHDR_LEN)
+ if (priv->rxlen >= IP_HDRLEN)
{
/* Handle the IP input. Get exclusive access to uIP. */
@@ -73,8 +73,8 @@
/* Configuration ************************************************************/
-#if NET_LLH_LEN > 0
-# error "NET_LLH_LEN must be set to zero"
+#if NET_LL_HDRLEN > 0
+# error "NET_LL_HDRLEN must be set to zero"
#endif
#ifndef CONFIG_NET_NOINTS
diff --git a/nuttx/net/tcp/tcp_input.c b/nuttx/net/tcp/tcp_input.c
index 7182275d1..5929eafae 100644
--- a/nuttx/net/tcp/tcp_input.c
+++ b/nuttx/net/tcp/tcp_input.c
@@ -64,7 +64,7 @@
* Pre-processor Definitions
****************************************************************************/
-#define BUF ((struct tcp_iphdr_s *)&dev->d_buf[NET_LLH_LEN])
+#define BUF ((struct tcp_iphdr_s *)&dev->d_buf[NET_LL_HDRLEN])
/****************************************************************************
* Public Variables
@@ -110,8 +110,8 @@ void tcp_input(struct net_driver_s *dev)
int len;
int i;
- dev->d_snddata = &dev->d_buf[UIP_IPTCPH_LEN + NET_LLH_LEN];
- dev->d_appdata = &dev->d_buf[UIP_IPTCPH_LEN + NET_LLH_LEN];
+ dev->d_snddata = &dev->d_buf[IPTCP_HDRLEN + NET_LL_HDRLEN];
+ dev->d_appdata = &dev->d_buf[IPTCP_HDRLEN + NET_LL_HDRLEN];
#ifdef CONFIG_NET_STATISTICS
g_netstats.tcp.recv++;
@@ -219,7 +219,7 @@ void tcp_input(struct net_driver_s *dev)
{
for (i = 0; i < ((pbuf->tcpoffset >> 4) - 5) << 2 ;)
{
- opt = dev->d_buf[UIP_TCPIP_HLEN + NET_LLH_LEN + i];
+ opt = dev->d_buf[IPTCP_HDRLEN + NET_LL_HDRLEN + i];
if (opt == TCP_OPT_END)
{
/* End of options. */
@@ -233,12 +233,12 @@ void tcp_input(struct net_driver_s *dev)
++i;
}
else if (opt == TCP_OPT_MSS &&
- dev->d_buf[UIP_TCPIP_HLEN + NET_LLH_LEN + 1 + i] == TCP_OPT_MSS_LEN)
+ dev->d_buf[IPTCP_HDRLEN + NET_LL_HDRLEN + 1 + i] == TCP_OPT_MSS_LEN)
{
/* An MSS option with the right option length. */
- tmp16 = ((uint16_t)dev->d_buf[UIP_TCPIP_HLEN + NET_LLH_LEN + 2 + i] << 8) |
- (uint16_t)dev->d_buf[UIP_IPTCPH_LEN + NET_LLH_LEN + 3 + i];
+ tmp16 = ((uint16_t)dev->d_buf[IPTCP_HDRLEN + NET_LL_HDRLEN + 2 + i] << 8) |
+ (uint16_t)dev->d_buf[IPTCP_HDRLEN + NET_LL_HDRLEN + 3 + i];
conn->mss = tmp16 > TCP_MSS ? TCP_MSS : tmp16;
/* And we are done processing options. */
@@ -251,7 +251,7 @@ void tcp_input(struct net_driver_s *dev)
* can skip past them.
*/
- if (dev->d_buf[UIP_TCPIP_HLEN + NET_LLH_LEN + 1 + i] == 0)
+ if (dev->d_buf[IPTCP_HDRLEN + NET_LL_HDRLEN + 1 + i] == 0)
{
/* If the length field is zero, the options are malformed
* and we don't process them further.
@@ -259,7 +259,7 @@ void tcp_input(struct net_driver_s *dev)
break;
}
- i += dev->d_buf[UIP_TCPIP_HLEN + NET_LLH_LEN + 1 + i];
+ i += dev->d_buf[IPTCP_HDRLEN + NET_LL_HDRLEN + 1 + i];
}
}
}
@@ -324,7 +324,7 @@ found:
* len) and the length of the IP header (20 bytes).
*/
- dev->d_len -= (len + IPHDR_LEN);
+ dev->d_len -= (len + IP_HDRLEN);
/* First, check if the sequence number of the incoming packet is
* what we're expecting next. If not, we send out an ACK with the
@@ -341,7 +341,7 @@ found:
if ((dev->d_len > 0 || ((pbuf->flags & (TCP_SYN | TCP_FIN)) != 0)) &&
memcmp(pbuf->seqno, conn->rcvseq, 4) != 0)
{
- tcp_send(dev, conn, TCP_ACK, UIP_IPTCPH_LEN);
+ tcp_send(dev, conn, TCP_ACK, IPTCP_HDRLEN);
return;
}
}
@@ -509,7 +509,7 @@ found:
{
for (i = 0; i < ((pbuf->tcpoffset >> 4) - 5) << 2 ;)
{
- opt = dev->d_buf[UIP_IPTCPH_LEN + NET_LLH_LEN + i];
+ opt = dev->d_buf[IPTCP_HDRLEN + NET_LL_HDRLEN + i];
if (opt == TCP_OPT_END)
{
/* End of options. */
@@ -523,13 +523,13 @@ found:
++i;
}
else if (opt == TCP_OPT_MSS &&
- dev->d_buf[UIP_TCPIP_HLEN + NET_LLH_LEN + 1 + i] == TCP_OPT_MSS_LEN)
+ dev->d_buf[IPTCP_HDRLEN + NET_LL_HDRLEN + 1 + i] == TCP_OPT_MSS_LEN)
{
/* An MSS option with the right option length. */
tmp16 =
- (dev->d_buf[UIP_TCPIP_HLEN + NET_LLH_LEN + 2 + i] << 8) |
- dev->d_buf[UIP_TCPIP_HLEN + NET_LLH_LEN + 3 + i];
+ (dev->d_buf[IPTCP_HDRLEN + NET_LL_HDRLEN + 2 + i] << 8) |
+ dev->d_buf[IPTCP_HDRLEN + NET_LL_HDRLEN + 3 + i];
conn->mss = tmp16 > TCP_MSS ? TCP_MSS : tmp16;
/* And we are done processing options. */
@@ -542,7 +542,7 @@ found:
* easily can skip past them.
*/
- if (dev->d_buf[UIP_TCPIP_HLEN + NET_LLH_LEN + 1 + i] == 0)
+ if (dev->d_buf[IPTCP_HDRLEN + NET_LL_HDRLEN + 1 + i] == 0)
{
/* If the length field is zero, the options are
* malformed and we don't process them further.
@@ -550,7 +550,7 @@ found:
break;
}
- i += dev->d_buf[UIP_TCPIP_HLEN + NET_LLH_LEN + 1 + i];
+ i += dev->d_buf[IPTCP_HDRLEN + NET_LL_HDRLEN + 1 + i];
}
}
}
@@ -639,7 +639,7 @@ found:
conn->nrtx = 0;
nllvdbg("TCP state: UIP_LAST_ACK\n");
- tcp_send(dev, conn, TCP_FIN | TCP_ACK, UIP_IPTCPH_LEN);
+ tcp_send(dev, conn, TCP_FIN | TCP_ACK, IPTCP_HDRLEN);
return;
}
@@ -692,7 +692,7 @@ found:
* When the application is called, the d_len field
* contains the length of the incoming data. The application can
* access the incoming data through the global pointer
* d_appdata, which usually points UIP_IPTCPH_LEN + NET_LLH_LEN
* bytes into the d_buf array.
*
* If the application wishes to send any data, this data should be
@@ -778,7 +778,7 @@ found:
net_incr32(conn->rcvseq, 1);
(void)tcp_callback(dev, conn, UIP_CLOSE);
- tcp_send(dev, conn, TCP_ACK, UIP_IPTCPH_LEN);
+ tcp_send(dev, conn, TCP_ACK, IPTCP_HDRLEN);
return;
}
else if ((flags & UIP_ACKDATA) != 0)
@@ -791,7 +791,7 @@ found:
if (dev->d_len > 0)
{
- tcp_send(dev, conn, TCP_ACK, UIP_IPTCPH_LEN);
+ tcp_send(dev, conn, TCP_ACK, IPTCP_HDRLEN);
return;
}
@@ -811,20 +811,20 @@ found:
net_incr32(conn->rcvseq, 1);
(void)tcp_callback(dev, conn, UIP_CLOSE);
- tcp_send(dev, conn, TCP_ACK, UIP_IPTCPH_LEN);
+ tcp_send(dev, conn, TCP_ACK, IPTCP_HDRLEN);
return;
}
if (dev->d_len > 0)
{
- tcp_send(dev, conn, TCP_ACK, UIP_IPTCPH_LEN);
+ tcp_send(dev, conn, TCP_ACK, IPTCP_HDRLEN);
return;
}
goto drop;
case UIP_TIME_WAIT:
- tcp_send(dev, conn, TCP_ACK, UIP_IPTCPH_LEN);
+ tcp_send(dev, conn, TCP_ACK, IPTCP_HDRLEN);
return;
case UIP_CLOSING:
@@ -692,7 +692,7 @@ found:
* contains the length of the incoming data. The application can
* access the incoming data through the global pointer
- * d_appdata, which usually points UIP_IPTCPH_LEN + NET_LLH_LEN
+ * d_appdata, which usually points IPTCP_HDRLEN + NET_LL_HDRLEN
* bytes into the d_buf array.
*